====
pcuf
====


.. image:: https://img.shields.io/pypi/v/pcuf.svg
        :target: https://pypi.python.org/pypi/pcuf


.. image:: https://codecov.io/gh/git-albertomarin/pcuf/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/git-albertomarin/pcuf


.. image:: https://img.shields.io/travis/git-albertomarin/pcuf.svg
        :target: https://travis-ci.org/git-albertomarin/pcuf

.. image:: https://readthedocs.org/projects/pcuf/badge/?version=latest
        :target: https://pcuf.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/git-albertomarin/pcuf/shield.svg
     :target: https://pyup.io/repos/github/git-albertomarin/pcuf/
     :alt: Updates



A personal collection of useful and frequently used Python functions.

Installing
----------

Install and update using pip:

.. code-block:: text

    pip install -U pcuf

Example Usage
-------------
pcuf can be imported and used within your own project like so.

.. code-block:: python

    import pcuf

Features
--------

* TODO


Links
---------------

* Documentation: https://pcuf.readthedocs.io.

